@@ -45,7 +45,12 @@ ggcall <- function(data = NULL,
                    ylim = NULL) {
   if (is.null(data))
     return(expr(ggplot()))
-  data <- sym(data)
+  data <- as.character(data)
+  if (grepl("::", data)) {
+    data <- str2lang(data) 
+  } else {
+    data <- sym(data)
+  }
   if (rlang::is_call(mapping)) 
     mapping <- eval(mapping)
   mapping <- dropNulls(mapping)
